from kvdroid.jclass.android import MediaPlayer, AudioManager


class Player(object):
    mPlayer = MediaPlayer(instantiate=True)
    content = None

    def raw(self):
        return self.mPlayer

    def play(self, content: str):
        self.content = content
        try:
            self.mPlayer.stop()
            self.mPlayer.reset()
        except:
            pass
        self.mPlayer.setDataSource(self.content)
        self.mPlayer.prepare()
        self.mPlayer.start()

    def pause(self):
        self.mPlayer.pause()

    def resume(self):
        self.mPlayer.start()

    def stop(self):
        self.mPlayer.stop()

    def stream(self, content: str):
        self.content = content
        self.mPlayer.setAudioStreamType(AudioManager().STREAM_MUSIC)
        try:
            self.mPlayer.stop()
            self.mPlayer.reset()
        except:
            pass
        self.mPlayer.setDataSource(self.content)
        self.mPlayer.prepare()
        self.mPlayer.start()

    def get_duration(self):
        if self.content:
            return self.mPlayer.getDuration()

    def current_position(self):
        if self.content:
            return self.mPlayer.getCurrentPosition()

    def seek(self, value: int):
        try:
            self.mPlayer.seekTo(value * 1000)
        except:
            pass

    def do_loop(self, loop=False):
        if not loop:
            self.mPlayer.setLooping(False)
        else:
            self.mPlayer.setLooping(True)

    def is_playing(self):
        return self.mPlayer.isPlaying()



from kvdroid.jclass.android import Uri

from kvdroid.jclass.android import Intent
from kvdroid import activity


def make_call(tel):
    intent = Intent(Intent().ACTION_CALL, Uri().parse(f"tel:{tel}"))
    activity.startActivity(intent)


def dial_call(tel):
    intent = Intent(Intent().ACTION_DIAL, Uri().parse(f"tel:{tel}"))
    activity.startActivity(intent)



from kvdroid.jclass.java.util import Locale

def device_lang(option = "Language", display_lang = None):
    locale = Locale().getDefault()
    options = {
        "Language" : locale.getLanguage() , 
        "ISO3Language" : locale.getISO3Language() ,
        "Country" : locale.getCountry() ,
        "ISO3Country" : locale.getISO3Country() ,
        "DisplayCountry" : locale.getDisplayCountry(Locale( str(display_lang) )) ,
        "DisplayName" : locale.getDisplayName(Locale( str(display_lang) )) ,
        "String" : locale.toString() ,
        "DisplayLanguage" : locale.getDisplayLanguage(Locale( str(display_lang) )) ,
        "LanguageTag" : locale.toLanguageTag() }

    if option not in options.keys():
        raise ValueError(f"Invalid option. Expected one of: {list(options.keys())}")
    else:
        return options[option]



from kvdroid.jclass.android import Activity
from kvdroid import activity


def network_status():
    if wifi_status() or mobile_status():
        return True
    else:
        return False
            
def wifi_status():
    from kvdroid.jclass.android import ConnectivityManager
    ConnectivityManager = ConnectivityManager()
    con_mgr = activity.getSystemService(Activity().CONNECTIVITY_SERVICE)
    try:
        return con_mgr.getNetworkInfo(ConnectivityManager.TYPE_WIFI).isConnectedOrConnecting()
    except:
        return False
            
def mobile_status():
    from kvdroid.jclass.android import ConnectivityManager
    ConnectivityManager = ConnectivityManager()
    con_mgr = activity.getSystemService(Activity().CONNECTIVITY_SERVICE)
    try:
        return con_mgr.getNetworkInfo(ConnectivityManager.TYPE_MOBILE).isConnectedOrConnecting()
    except:
        return False



from jnius import autoclass
from kvdroid.jclass import _class_call


def Color(*args, instantiate: bool = False):
    return _class_call(autoclass("android.graphics.Color"), args, instantiate)


def Rect(*args, instantiate: bool = False):
    return _class_call(autoclass('android.graphics.Rect'), args, instantiate)


def BitmapFactory(*args, instantiate: bool = False):
    return _class_call(autoclass('android.graphics.BitmapFactory'), args, instantiate)


def Point(*args, instantiate: bool = False):
    return _class_call(autoclass("android.graphics.Point"), args, instantiate)


from jnius import autoclass
from kvdroid.jclass import _class_call


def CookieManager(*args, instantiate: bool = False):
    return _class_call(autoclass("android.webkit.CookieManager"), args, instantiate)



from jnius import autoclass
from kvdroid.jclass import _class_call


def Settings(*args, instantiate: bool = False):
    return _class_call(autoclass('android.provider.Settings'), args, instantiate)


def Contacts(*args, instantiate: bool = False):
    return _class_call(autoclass('android.provider.ContactsContract$Contacts'), args, instantiate)


def Phone(*args, instantiate: bool = False):
    return _class_call(
        autoclass('android.provider.ContactsContract$CommonDataKinds$Phone'),
        args, instantiate)



from .content.res import *
from .content import *
from .speech.tts import *
from .speech import *
from .app import *
from .graphics import *
from .media import *
from .net import *
from .os import *
from .provider import *
from .view import *
from .webkit import *
from .widget import *
